DO $$
DECLARE
  shopRef							int8 = 		(select id from oms."ShopDO" where "internalShopName"='inTRONICS');
  supplierRef						int8;
  paymentProviderRef				int8 =		1;
  closeInvoicingQueue				int8 = 		(select id from "ProcessesDO" where "processDefRef" = (select id from "ProcessDefDO" where "queueName" = 'CloseInvoicingQueue'));
  eventControlQueue					int8 = 		(select id from "ProcessesDO" where "processDefRef" = (select id from "ProcessDefDO" where "queueName" = 'EventControlQueue'));
  invoicingTransmissionSyncQueue	int8 = 		(select id from "ProcessesDO" where "processDefRef" = (select id from "ProcessDefDO" where "queueName" = 'InvoicingTransmissionSyncQueue'));
  objectTypeDefRef					int8 = 		(select id from "ObjectTypeDefDO" where "name" = 'Invoicing');
  transmissionTypeDefRef			int8 =		320;
  processControlConfigRef			int8;
  processControlLineConfigRef		int8;
  eventRegistryEntryRef				int8;
  eventDefRef						int8;
  paymentEventDefRef				int8;
  communicationRef					int8;
  communicationPartnerRef			int8;
  decisionBeanDefRef				int8;
  sendingPartnerReferrerRef			int8;
  receivingPartnerReferrerRef		int8;
  paymentNotificationActionDefRef	int8;
  paymentDefRef						int8;
  shop2PaymentProvider2PaymentRef	int8;
  doProcess							boolean;
  doManualApprove					boolean;
  

BEGIN

-- CommunicationDO for INTERNAL_SEND_PAYMENT_NOTIFICATION_BEAN if not exists
INSERT INTO "CommunicationDO" (id, active, "activeOMT", key, "documentFormatDefRef", "executionBeanDefRef", "transmissionTypeDefRef", "communicationVersionDefRef", "transmissionFormDefRef") 
	SELECT nextval('"CommunicationDO_id_seq"'), true, false, 'INTERNAL_SEND_PAYMENT_NOTIFICATION_BEAN', 2, 1, transmissionTypeDefRef, 1, 10
	WHERE NOT EXISTS(SELECT 1 from "CommunicationDO" where "executionBeanDefRef" = 1 and "transmissionTypeDefRef" = transmissionTypeDefRef);
		
--#################################
--# Payment provider configuration
--#################################
INSERT INTO "PaymentProviderDO"(id, "modificationDate", name, "partlyCaptureAllowed", "partlyReverseAllowed")
    SELECT paymentProviderRef, now(), 'SCE 4.0 Payment Provider', true, false
	WHERE NOT EXISTS(SELECT * FROM "PaymentProviderDO" WHERE id = paymentProviderRef);

INSERT INTO "PartnerReferrerDO" (id,version,"paymentProviderRef")
SELECT nextval('"PartnerReferrerDO_id_seq"'),0,paymentProviderRef
WHERE NOT EXISTS(SELECT * FROM "PartnerReferrerDO" WHERE "paymentProviderRef" = paymentProviderRef);

--#############################################################################
--# Mapping Shop to Paymentprovider to Paymentmethod for all supported methods
--#############################################################################
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 1);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 2);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 3);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 4);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 5);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 6);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 10);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 24);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 100);
perform admin.add_shop_to_payment_provider_to_payment(shopRef, paymentProviderRef, 40);
	
--###########################################################################################################
--# Communication partner configuration using INTERNAL_SEND_PAYMENT_NOTIFICATION_BEAN as dummy MessageSender
--# Sending partner --> Shop
--# Receiving partner --> Paymentprovider
--###########################################################################################################
sendingPartnerReferrerRef := (select id from "PartnerReferrerDO" where "shopRef" = shopRef);
receivingPartnerReferrerRef := (select id from "PartnerReferrerDO" where "paymentProviderRef" = paymentProviderRef);
communicationRef := (select id from "CommunicationDO" where "executionBeanDefRef" = 1 and "transmissionTypeDefRef" = transmissionTypeDefRef);
communicationPartnerRef = admin.add_communication_partner(NULL, false, communicationRef, sendingPartnerReferrerRef, receivingPartnerReferrerRef);
		
--###########################################################
--# Event registry configuration
--# Trigger Payment Event Manager on CloseInvoicingQueue
--###########################################################
eventDefRef := 2; -- payment event
eventRegistryEntryRef := admin.add_event_registry_entry(closeInvoicingQueue, shopRef, eventDefRef, 'Payment Events on CloseInvoicingQueue');

--#############################################################
--# Payment Event registry configuration
--# Add payment events for each payment method and all actions
--#############################################################
paymentEventDefRef := 10; -- CREATE_PAYMENTNOTIFICATION
decisionBeanDefRef := 70; -- PAYMENT_ACTION_DECIDER_BEAN

-- Capture for Credit cards (3)
paymentDefRef := 3;
paymentNotificationActionDefRef := 3; -- capture
perform admin.add_payment_event_registry_entry(eventRegistryEntryRef, paymentEventDefRef, paymentDefRef, paymentNotificationActionDefRef, decisionBeanDefRef);

-- Refund for Credit cards (3)
paymentDefRef := 3;
paymentNotificationActionDefRef := 4; -- refund
perform admin.add_payment_event_registry_entry(eventRegistryEntryRef, paymentEventDefRef, paymentDefRef, paymentNotificationActionDefRef, decisionBeanDefRef);

-- Capture for paypal (10)
paymentDefRef := 10;
paymentNotificationActionDefRef := 3; -- capture
perform admin.add_payment_event_registry_entry(eventRegistryEntryRef, paymentEventDefRef, paymentDefRef, paymentNotificationActionDefRef, decisionBeanDefRef);

-- Refund for paypal (10)
paymentDefRef := 10;
paymentNotificationActionDefRef := 4; -- refund
perform admin.add_payment_event_registry_entry(eventRegistryEntryRef, paymentEventDefRef, paymentDefRef, paymentNotificationActionDefRef, decisionBeanDefRef);

--###################################################################
--# Payment action configuration
--#  -- required for all payment events
--#  -- doProcess = false --> no transmission
--#  -- doManualApprove = true --> approval required for this action
--###################################################################
-- PaymentActionApprovalDefDO TRUE,FALSE for Credit cards(3) und CAPTURE  
paymentNotificationActionDefRef := 3; -- capture
paymentDefRef := 3;
shop2PaymentProvider2PaymentRef := (select id from "Shop2PaymentProvider2PaymentDefDO"  where "shopRef" = shopRef and "paymentDefRef" = paymentDefRef);
doProcess := true;
doManualApprove := false;
perform admin.add_payment_action_approval(paymentNotificationActionDefRef, shop2PaymentProvider2PaymentRef, doProcess, doManualApprove);  

-- PaymentActionApprovalDefDO TRUE,FALSE for credit cards (3) und REFUND          
paymentNotificationActionDefRef := 4; -- refund
paymentDefRef := 3;
shop2PaymentProvider2PaymentRef := (select id from "Shop2PaymentProvider2PaymentDefDO"  where "shopRef" = shopRef and "paymentDefRef" = paymentDefRef);
doProcess := true;
doManualApprove := false;
perform admin.add_payment_action_approval(paymentNotificationActionDefRef, shop2PaymentProvider2PaymentRef, doProcess, doManualApprove);

-- PaymentActionApprovalDefDO FALSE,FALSE for PayPal(10) und CAPTURE  
paymentNotificationActionDefRef := 3; -- capture
paymentDefRef := 10;
shop2PaymentProvider2PaymentRef := (select id from "Shop2PaymentProvider2PaymentDefDO"  where "shopRef" = shopRef and "paymentDefRef" = paymentDefRef);
doProcess := false;
doManualApprove := false;
perform admin.add_payment_action_approval(paymentNotificationActionDefRef, shop2PaymentProvider2PaymentRef, doProcess, doManualApprove);  

-- PaymentActionApprovalDefDO TRUE,FALSE for PayPal(10) und REFUND          
paymentNotificationActionDefRef := 4; -- refund
paymentDefRef := 10;
shop2PaymentProvider2PaymentRef := (select id from "Shop2PaymentProvider2PaymentDefDO"  where "shopRef" = shopRef and "paymentDefRef" = paymentDefRef);
doProcess := true;
doManualApprove := false;
perform admin.add_payment_action_approval(paymentNotificationActionDefRef, shop2PaymentProvider2PaymentRef, doProcess, doManualApprove);

END;
$$;